#!/bin/sh
#
#  IBM Confidential OCO Source Material
#
#  5724-I63, 5724-H88, 5655-N02, 5733-W70 (C) COPYRIGHT International Business Machines Corp. 2004, 2005
#
#  The source code for this program is not published or otherwise divested
#  of its trade secrets, irrespective of what has been deposited with the
#  U.S. Copyright Office.
#
# ----------------------------------------------------------------------------
# Description:   Creates the Common Event Infrastructure database for Informix
#                This script must be executed where the proper Informix
#                environment is configured. The script uses dbaccess to execute
#                SQL scripts, which may only be available on the Informix
#                server. This script must be executed by a user with create
#                database privileges. In Windows, this would a user that is a
#                member of the Informix-Admin group.
#
# Usage: ./cr_event_informix.sh
#
#
# Return Codes:  0 for success, non 0 for errors
# --------------------------------------------------------------------------

rc=0

# --------------------------------------------------------------------------
# creates the dbspaces for the event database
# --------------------------------------------------------------------------
create_dbspaces() {

  # Create directories
  SCRIPT_DIR="##DB_SYSTEM_DIR#"
  if [ -d "$SCRIPT_DIR" ] ; then
     chmod ug+rwx "$SCRIPT_DIR"
  else
     mkdir -p "$SCRIPT_DIR"
     chown ##schema# "$SCRIPT_DIR"
     chgrp informix "$SCRIPT_DIR"
     chmod ug+rwx "$SCRIPT_DIR"
  fi

  # The files must exist before using the onspaces command
  # Size is in KB
  # create dbspaces

  # dbspace for the system tables
  touch "$SCRIPT_DIR/##EVENT_SYSTEM_PATH#"
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  chmod 660 "$SCRIPT_DIR/##EVENT_SYSTEM_PATH#"
  chown ##schema# "$SCRIPT_DIR/##EVENT_SYSTEM_PATH#"
  chgrp informix "$SCRIPT_DIR/##EVENT_SYSTEM_PATH#"

  echo "onspaces -c -d ##EVENT_SYSTEM_NAME# $SCRIPT_DIR/##EVENT_SYSTEM_PATH# -o 0 -s ##EVENT_SYSTEM_SIZE#"
  onspaces -c -d ##EVENT_SYSTEM_NAME# -p "$SCRIPT_DIR/##EVENT_SYSTEM_PATH#" -o 0 -s ##EVENT_SYSTEM_SIZE#
   return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  touch "$SCRIPT_DIR/##EVENT_BASE_PATH#"
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  chmod 660 "$SCRIPT_DIR/##EVENT_BASE_PATH#"
  chown ##schema# "$SCRIPT_DIR/##EVENT_BASE_PATH#"
  chgrp informix "$SCRIPT_DIR/##EVENT_BASE_PATH#"

  echo "onspaces -c -d ##EVENT_BASE_NAME# $SCRIPT_DIR/##EVENT_BASE_PATH# -o 0 -s ##EVENT_BASE_SIZE#"
  onspaces -c -d ##EVENT_BASE_NAME# -p "$SCRIPT_DIR/##EVENT_BASE_PATH#" -o 0 -s ##EVENT_BASE_SIZE#
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  touch "$SCRIPT_DIR/##EVENT_EXTENDED_PATH#"
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  chmod 660 "$SCRIPT_DIR/##EVENT_EXTENDED_PATH#"
  chown ##schema# "$SCRIPT_DIR/##EVENT_EXTENDED_PATH#"
  chgrp informix "$SCRIPT_DIR/##EVENT_EXTENDED_PATH#"

  echo "onspaces -c -d ##EVENT_EXTENDED_NAME# $SCRIPT_DIR/##EVENT_EXTENDED_PATH# -o 0 -s ##EVENT_EXTENDED_SIZE#"
  onspaces -c -d ##EVENT_EXTENDED_NAME# -p "$SCRIPT_DIR/##EVENT_EXTENDED_PATH#" -o 0 -s ##EVENT_EXTENDED_SIZE#
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  #Smart BLOB space for CLOB and BLOB data. The size MUST be a multiple of the
  # BLOB page size!
  touch "$SCRIPT_DIR/##EVENT_BLOB_PATH#"
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  chmod 660 "$SCRIPT_DIR/##EVENT_BLOB_PATH#"
  chown ##schema# "$SCRIPT_DIR/##EVENT_BLOB_PATH#"
  chgrp informix "$SCRIPT_DIR/##EVENT_BLOB_PATH#"

  echo "onspaces -c -d ##EVENT_BLOB_NAME# $SCRIPT_DIR/##EVENT_BLOB_PATH# -o 0 -s ##EVENT_BLOB_SIZE#"
  onspaces -c -b ##EVENT_BLOB_NAME# -g ##EVENT_BLOB_PAGE_SIZE# -p "$SCRIPT_DIR/##EVENT_BLOB_PATH#" -o 0 -s ##EVENT_BLOB_SIZE#
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  touch "$SCRIPT_DIR/##EVENT_CATALOG_PATH#"
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  chmod 660 "$SCRIPT_DIR/##EVENT_CATALOG_PATH#"
  chown ##schema# "$SCRIPT_DIR/##EVENT_CATALOG_PATH#"
  chgrp informix "$SCRIPT_DIR/##EVENT_CATALOG_PATH#"

  echo "onspaces -c -d ##EVENT_CATALOG_NAME# $SCRIPT_DIR/##EVENT_CATALOG_PATH# -o 0 -s ##EVENT_CATALOG_SIZE#"
  onspaces -c -d ##EVENT_CATALOG_NAME# -p "$SCRIPT_DIR/##EVENT_CATALOG_PATH#" -o 0 -s ##EVENT_CATALOG_SIZE#
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  touch "$SCRIPT_DIR/##EVENT_CATALOG_BLOB_PATH#"
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi

  chmod 660 "$SCRIPT_DIR/##EVENT_CATALOG_BLOB_PATH#"
  chown ##schema# "$SCRIPT_DIR/##EVENT_CATALOG_BLOB_PATH#"
  chgrp informix "$SCRIPT_DIR/##EVENT_CATALOG_BLOB_PATH#"

  echo "onspaces -c -d ##EVENT_CATALOG_BLOB_NAME# $SCRIPT_DIR/##EVENT_CATALOG_BLOB_PATH# -o 0 -s ##EVENT_CATALOG_BLOB_SIZE#"
  #the size MUST be a multiple of the page size
  onspaces -c -b ##EVENT_CATALOG_BLOB_NAME# -g ##EVENT_CATALOG_BLOB_PAGE_SIZE# -p "$SCRIPT_DIR/##EVENT_CATALOG_BLOB_PATH#" -o 0 -s ##EVENT_CATALOG_BLOB_SIZE#
  return_code=$?
  if [ $return_code -gt $rc ] ; then
    rc=$return_code
    return
  fi

  if [ $rc -gt 0 ] ; then
    return
  fi
}

# --------------------------------------------------------------------------
# Execute the scripts that create the database, tables, populate the meta
# data
# --------------------------------------------------------------------------
execute_scripts()  {

  CURRENT_DIR=`dirname $0`
  if [ "$CURRENT_DIR" = "." ] ; then
     CURRENT_DIR=`pwd`
  fi

  SCRIPT_LIST="$CURRENT_DIR/cr_db.sql \
   $CURRENT_DIR/cr_tbl.sql \
   $CURRENT_DIR/cr_tbl_catalog.sql \
   $CURRENT_DIR/cr_stored_procedure.sql \
   $CURRENT_DIR/ins_metadata.sql \
   $CURRENT_DIR/catalogSeed.sql"

  for SCRIPT in $SCRIPT_LIST; do
    if [ $rc -eq 0 ] ; then
      echo "dbaccess - $SCRIPT"
      dbaccess - $SCRIPT
      return_code=$?
      if [ $return_code -gt $rc ] ; then
        rc=$return_code
        return
      fi

      if [ $rc -gt 0 ] ; then
        exit $rc
      fi
    fi
  done
}

# --------------------------------------------------------------------------
# Initialize Informix Environment
# --------------------------------------------------------------------------
init_env() {
   export INFORMIXDIR=##DB_INFORMIX_DIR#
   export INFORMIXSERVER=##DB_SERVER_NAME#
   export PATH=$INFORMIXDIR/bin:$PATH
}

#initialize Informix environment
init_env

#Create the dbspaces
create_dbspaces

#Create the database, tables, etc.
if [ $rc -eq 0 ] ; then
  execute_scripts
fi

exit $rc
